"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
/**
 * Will return callback function that will keep the same reference
 * during entire lifetime of the component, but when called,
 * will always use 'fresh' version of callback from last render
 *
 */
function useConstCallback(callback) {
    /**
     * Remember 'fresh' callback function in ref during every render
     */
    const callbackRef = react_1.useRef(callback);
    callbackRef.current = callback;
    /**
     * Create actuall callback that will never change, but which under the hood
     * is always using the latest version of the callback function
     */
    const constantCallback = react_1.useCallback((...args) => {
        return callbackRef.current(...args);
    }, []);
    return constantCallback;
}
exports.useConstCallback = useConstCallback;
exports.default = useConstCallback;
